==> jboss-eap-7.2.3-src.zip: jboss-eap-7.2-src/testsuite/integration/basic/src/test/java/org/jboss/as/test/integration/ejb/interceptor/classinherit/StatelessWithBeanInterceptorBean.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2011, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.test.integration.ejb.interceptor.classinherit;

import javax.interceptor.Interceptors;
import javax.ejb.Stateless;

/**
 *
 * @author <a href="kabir.khan@jboss.com">Kabir Khan</a>
 */
@Stateless
@Interceptors({ TestInterceptor.class })
public class StatelessWithBeanInterceptorBean extends AbstractBaseClassWithInterceptor implements StatelessRemote {
    public String method() {
        return StatelessWithBeanInterceptorBean.class.getSimpleName() + ".method()";
    }

    public String superMethod() {
        return StatelessWithBeanInterceptorBean.class.getSimpleName() + ".superMethod()";
    }
}

==> jboss-eap-8.0.6-src.zip: jboss-eap-8.0-src/testsuite/integration/basic/src/test/java/org/jboss/as/test/integration/ejb/interceptor/classinherit/StatelessWithBeanInterceptorBean.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2011, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.test.integration.ejb.interceptor.classinherit;

import jakarta.interceptor.Interceptors;
import jakarta.ejb.Stateless;

/**
 *
 * @author <a href="kabir.khan@jboss.com">Kabir Khan</a>
 */
@Stateless
@Interceptors({ TestInterceptor.class })
public class StatelessWithBeanInterceptorBean extends AbstractBaseClassWithInterceptor implements StatelessRemote {
    public String method() {
        return StatelessWithBeanInterceptorBean.class.getSimpleName() + ".method()";
    }

    public String superMethod() {
        return StatelessWithBeanInterceptorBean.class.getSimpleName() + ".superMethod()";
    }
}
